# include "global.h"
#include "io.h"
#include "timestepping.h"

int main(int argc, char **argv)
{
  // Declare local variables
  FILE *outputFile;
  double t;
  double nextPrintOutTime;
  double startTimer;
  double finishTimer;
  int i;

  // Declare local arrays
  double *v1;
  double *H1;

  // Assign any global variables which do not acquire values from the parameter file
  M=3;

  //  Read parameter file
  if(readParameterFile(argv[1])!=0)
  { fprintf(stderr, "Failed to read parameters from file %s\n",argv[1]);
    fflush(stderr);
    exit(-1);}
  printParameters(stderr);  


  // Allocate memory
  v1=(double *)calloc(M,sizeof(double));
  H1=(double *)calloc(M,sizeof(double));

  // Set initial condition
  t=0;
  nextPrintOutTime=0;
  v1[0]=V0;
  v1[1]=V1;
  v1[2]=V2;
   
  // Open the output file to store results
  outputFile=fopen(argv[2],"w");
  // Check that it worked
  if(outputFile==NULL)
  { goto ERROR1;}

  // Measure the start time
  startTimer=(double)clock();

  // Perform computation
  while(t<endTime)
  {
    if(t>=nextPrintOutTime)
    {
       // Produce intermediate output
       fprintf(outputFile,"%le",t);
       for(i=0;i<M;i++)
       {
         fprintf(outputFile," %le",v1[i]);
       }
       fprintf(outputFile,"\n");

       // Update the next time to produce output
       nextPrintOutTime=nextPrintOutTime+Delta;
    }
    
    simpleEuler(v1, H1);

    // Update the time variable
    t=t+dt;
  }

  fclose(outputFile);
 
  // Measure the end time and print the run time
  finishTimer=(double)clock();
  fprintf (stderr,"\tApproximate CPU time:        %le s\n", (double) (finishTimer - startTimer)/CLOCKS_PER_SEC);
  
  // Deallocate memory and close output file
  free(v1);
  free(H1);
  exit(0);

// Print sensible error messages if something went wrong
ERROR1:
   fprintf(stderr,"Failed to open file %s\n", argv[2]); 
   fflush(stderr);
   exit(-1);
}
